** Summarize results to produce appendix table 2 **
set more off

capture cd "C:\Users\pei\Dropbox\rdd3\graphs"
capture cd "C:\Users\user\Dropbox\RA_Pei\Suejin_Lee\rkd_aie_RA_Suejin"

use "data\sim_emp_kink3_nk_quintic_summary_ll.dta", clear

log using "logs\appendix-table2.log", replace

cap drop absdev* devsq*
scalar truekink = 0
scalar truefs = 2.3*10^(-5)

foreach k in CCT CCTnoreg fuzzyCCT fuzzyCERCCT FG max {

	rename bw_`k' bw_l_`k'
	rename b_bw_`k' b_bw_l_`k'
	
	gen bw_r_`k' = bw_l_`k'
	gen b_bw_r_`k' = b_bw_l_`k'
	
}

local bws "CCT CCTnoreg fuzzyCCT fuzzyTWO fuzzyCERCCT fuzzyCERTWO FG max"
foreach k of local bws { 

	qui gen absdev_cl_`k' = abs(tau_F_cl_`k' - truekink)
	qui gen devsq_cl_`k' = (tau_F_cl_`k'-truekink)^2
	qui gen devsq_T_cl_`k' = (tau_T_cl_`k'-truefs)^2
	qui gen dev_cl_`k' = tau_F_cl_`k'-truekink
	qui gen cover_zero_T_cl_`k' = (ci_upper_T_cl_`k'>0 & ci_lower_T_cl_`k' <0)
	
	qui sum devsq_cl_`k', d
	scalar rmse_cl_`k' = sqrt(r(mean)) 
	scalar tcutoff_cl_`k' = r(p95)
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar trmse_cl_`k' = sqrt(r(mean))
	
	qui sum dev_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tbias_cl_`k' = r(mean)
	
	qui sum tau_F_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tvar_cl_`k' = r(sd)^2

	
	qui sum absdev_cl_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_cl_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_cl_`k' if absdev_cl_`k'<r(p95)
	scalar tadr_cl_`k' = r(mean)
	
	
	//di "Coverage rates"
	qui sum cover_cl_`k'
	scalar cr_cl_`k' = r(mean)

	
	qui sum devsq_T_cl_`k'
	scalar rmse_T_cl_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_cl_`k'
	scalar cr_zero_T_cl_`k' = r(mean)
	
	qui sum cover_T_cl_`k'
	scalar cr_T_cl_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
	
	}

	
foreach k of local bws { 

	qui gen absdev_bc_`k' = abs(tau_F_bc_`k' - truekink)
	qui gen devsq_bc_`k' = (tau_F_bc_`k'-truekink)^2
	qui gen devsq_T_bc_`k' = (tau_T_bc_`k'-truefs)^2
	qui gen dev_bc_`k' = tau_F_bc_`k'-truekink
	qui gen cover_zero_T_rb_`k' = (ci_upper_T_rb_`k'>0 & ci_lower_T_rb_`k' <0)
		
	
	qui sum devsq_bc_`k', d
	scalar rmse_bc_`k' = sqrt(r(mean)) 
 	scalar tcutoff_bc_`k' = r(p95)
	
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar trmse_bc_`k' = sqrt(r(mean)) 
	
	qui sum dev_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tbias_bc_`k' = r(mean)
	
	qui sum tau_F_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tvar_rb_`k' = r(sd)^2
	
	
	
	qui sum absdev_bc_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_bc_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_bc_`k' if absdev_bc_`k'<r(p95)
	scalar tadr_bc_`k' = r(mean)

	qui sum devsq_T_bc_`k'
	scalar rmse_T_bc_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_rb_`k'
	scalar cr_zero_T_rb_`k' = r(mean)
	
	qui sum cover_T_rb_`k'
	scalar cr_T_rb_`k' = r(mean)	
	
	//di "Coverage rates"
	qui sum cover_rb_`k'
	scalar cr_rb_`k' = r(mean)
	
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
	
	}

scalar mbw_max = 4564
scalar pbw_max = 4564
						
di "BW Method " "RMSE  " "TRMSE  " "Coverage IV " "Coverage FS " "FS Cover 0 " "FS MSE " "Main BW (Left/right)" "Pilot BW (Left/right)"

foreach k of local bws { 

	di "`k'" " " rmse_cl_`k' " " trmse_cl_`k' " " cr_cl_`k' " " cr_T_cl_`k' " " cr_zero_T_cl_`k' " " rmse_T_cl_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_cl_`k' " " tbias_cl_`k'^2 " " tvar_cl_`k'
	
						}		

					
foreach k of local bws { 

	di "`k'" " " rmse_bc_`k' " " trmse_bc_`k' " " cr_rb_`k' " " cr_T_rb_`k' " " cr_zero_T_rb_`k' " " rmse_T_bc_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_bc_`k' " " tbias_bc_`k'^2 " " tvar_rb_`k'
	
						}	

/*
histogram tau_F_cl_FG, xline(1.3) xtitle("Local Linear FG Estimate") title("Distribution of Local Linear FG Estimate: Bottom Kink Quintic DGP")
graph export "C:\Users\pei\Dropbox\rdd3\graphs\dist_estimate_kink3_nk_quintic_llFG.pdf", as(pdf) replace												
*/						
/*						
foreach k of local bws { 

	qui sum absdev_cl_`k', d
				
	scatter absdev_cl_`k' Fstat_T_cl_`k' if absdev_cl_`k'<r(p95), saving(devcl_vs_Fcl_k3_`k'_ll.gph, replace)						

						}

graph combine devcl_vs_Fcl_k3_CCT_ll.gph devcl_vs_Fcl_k3_CCTnoreg_ll.gph devcl_vs_Fcl_k3_fuzzyCCT_ll.gph devcl_vs_Fcl_k3_fuzzyIK_ll.gph	devcl_vs_Fcl_k3_FG_ll.gph	///
devcl_vs_Fcl_k3_max_ll.gph, saving(devcl_vs_Fcl_k3_ll.gph, replace)			
						

foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' Fstat_T_cl_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_Fcl_k3_`k'_ll.gph, replace)						

						}
						
graph combine devbc_vs_Fcl_k3_CCT_ll.gph devbc_vs_Fcl_k3_CCTnoreg_ll.gph devbc_vs_Fcl_k3_fuzzyCCT_ll.gph devbc_vs_Fcl_k3_fuzzyIK_ll.gph	devbc_vs_Fcl_k3_FG_ll.gph	///
devbc_vs_Fcl_k3_max_ll.gph, saving(devbc_vs_Fcl_k3_ll.gph, replace)							

		
foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' t_T_rb_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_trb_k3_`k'_ll.gph, replace)						

						}
						
graph combine devbc_vs_trb_k3_CCT_ll.gph devbc_vs_trb_k3_CCTnoreg_ll.gph devbc_vs_trb_k3_fuzzyCCT_ll.gph devbc_vs_trb_k3_fuzzyIK_ll.gph	devbc_vs_trb_k3_FG_ll.gph	///
devbc_vs_trb_k3_max_ll.gph, saving(devbc_vs_trb_k3_ll.gph, replace)			
*/								
						
use "data\sim_emp_kink3_nk_quintic_summary_lq.dta", clear

cap drop absdev* devsq*
scalar truekink = 0
scalar truefs = 2.3*10^(-5)

foreach k in CCT CCTnoreg fuzzyCCT fuzzyCERCCT FG max {

	rename bw_`k' bw_l_`k'
	rename b_bw_`k' b_bw_l_`k'
	
	gen bw_r_`k' = bw_l_`k'
	gen b_bw_r_`k' = b_bw_l_`k'
	
}

local bws "CCT CCTnoreg fuzzyCCT fuzzyTWO fuzzyCERCCT fuzzyCERTWO FG max"
foreach k of local bws { 

	qui gen absdev_cl_`k' = abs(tau_F_cl_`k' - truekink)
	qui gen devsq_cl_`k' = (tau_F_cl_`k'-truekink)^2
	qui gen devsq_T_cl_`k' = (tau_T_cl_`k'-truefs)^2
	qui gen dev_cl_`k' = tau_F_cl_`k'-truekink
	qui gen cover_zero_T_cl_`k' = (ci_upper_T_cl_`k'>0 & ci_lower_T_cl_`k' <0)
	
	qui sum devsq_cl_`k', d
	scalar rmse_cl_`k' = sqrt(r(mean)) 
	scalar tcutoff_cl_`k' = r(p95)
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar trmse_cl_`k' = sqrt(r(mean))
	
	qui sum dev_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tbias_cl_`k' = r(mean)
	
	qui sum tau_F_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tvar_cl_`k' = r(sd)^2

	
	qui sum absdev_cl_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_cl_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_cl_`k' if absdev_cl_`k'<r(p95)
	scalar tadr_cl_`k' = r(mean)
	
	
	//di "Coverage rates"
	qui sum cover_cl_`k'
	scalar cr_cl_`k' = r(mean)

	
	qui sum devsq_T_cl_`k'
	scalar rmse_T_cl_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_cl_`k'
	scalar cr_zero_T_cl_`k' = r(mean)
	
	qui sum cover_T_cl_`k'
	scalar cr_T_cl_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
		
	}

	
foreach k of local bws { 

	qui gen absdev_bc_`k' = abs(tau_F_bc_`k' - truekink)
	qui gen devsq_bc_`k' = (tau_F_bc_`k'-truekink)^2
	qui gen devsq_T_bc_`k' = (tau_T_bc_`k'-truefs)^2
	qui gen dev_bc_`k' = tau_F_bc_`k'-truekink
	qui gen cover_zero_T_rb_`k' = (ci_upper_T_rb_`k'>0 & ci_lower_T_rb_`k' <0)
		
	
	qui sum devsq_bc_`k', d
	scalar rmse_bc_`k' = sqrt(r(mean)) 
 	scalar tcutoff_bc_`k' = r(p95)
	
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar trmse_bc_`k' = sqrt(r(mean)) 
	
	qui sum dev_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tbias_bc_`k' = r(mean)
	
	qui sum tau_F_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tvar_rb_`k' = r(sd)^2
	
	
	
	qui sum absdev_bc_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_bc_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_bc_`k' if absdev_bc_`k'<r(p95)
	scalar tadr_bc_`k' = r(mean)

	qui sum devsq_T_bc_`k'
	scalar rmse_T_bc_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_rb_`k'
	scalar cr_zero_T_rb_`k' = r(mean)
	
	qui sum cover_T_rb_`k'
	scalar cr_T_rb_`k' = r(mean)	
	
	//di "Coverage rates"
	qui sum cover_rb_`k'
	scalar cr_rb_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
	
	
	}

scalar mbw_max = 4564
scalar pbw_max = 4564
						
							
di "BW Method " "RMSE  " "TRMSE  " "Coverage IV " "Coverage FS " "FS Cover 0 " "FS MSE " "Main BW (Left/right)" "Pilot BW (Left/right)"

foreach k of local bws { 

	di "`k'" " " rmse_cl_`k' " " trmse_cl_`k' " " cr_cl_`k' " " cr_T_cl_`k' " " cr_zero_T_cl_`k' " " rmse_T_cl_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_cl_`k' " " tbias_cl_`k'^2 " " tvar_cl_`k'
	
						}		

					
foreach k of local bws { 

	di "`k'" " " rmse_bc_`k' " " trmse_bc_`k' " " cr_rb_`k' " " cr_T_rb_`k' " " cr_zero_T_rb_`k' " " rmse_T_bc_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_bc_`k' " " tbias_bc_`k'^2 " " tvar_rb_`k'
	
						}	

/*						
foreach k of local bws { 

	qui sum absdev_cl_`k', d
				
	scatter absdev_cl_`k' Fstat_T_cl_`k' if absdev_cl_`k'<r(p95), saving(devcl_vs_Fcl_k3_`k'_lq.gph, replace)						

						}

graph combine devcl_vs_Fcl_k3_CCT_lq.gph devcl_vs_Fcl_k3_CCTnoreg_lq.gph devcl_vs_Fcl_k3_fuzzyCCT_lq.gph devcl_vs_Fcl_k3_fuzzyIK_lq.gph	devcl_vs_Fcl_k3_FG_lq.gph	///
devcl_vs_Fcl_k3_max_lq.gph, saving(devcl_vs_Fcl_k3_lq.gph, replace)			
						

foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' Fstat_T_cl_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_Fcl_k3_`k'_lq.gph, replace)						

						}
						
graph combine devbc_vs_Fcl_k3_CCT_lq.gph devbc_vs_Fcl_k3_CCTnoreg_lq.gph devbc_vs_Fcl_k3_fuzzyCCT_lq.gph devbc_vs_Fcl_k3_fuzzyIK_lq.gph	devbc_vs_Fcl_k3_FG_lq.gph	///
devbc_vs_Fcl_k3_max_lq.gph, saving(devbc_vs_Fcl_k3_lq.gph, replace)							

		
foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' t_T_rb_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_trb_k3_`k'_lq.gph, replace)						

						}
						
graph combine devbc_vs_trb_k3_CCT_lq.gph devbc_vs_trb_k3_CCTnoreg_lq.gph devbc_vs_trb_k3_fuzzyCCT_lq.gph devbc_vs_trb_k3_fuzzyIK_lq.gph	devbc_vs_trb_k3_FG_lq.gph	///
devbc_vs_trb_k3_max_lq.gph, saving(devbc_vs_trb_k3_lq.gph, replace)							
*/						
						
						
use "data\sim_emp_kink4_nk_quintic_summary_ll.dta", clear

cap drop absdev* devsq*						
scalar truekink = 0
scalar truefs = -1.4*10^(-5)						
						
foreach k in CCT CCTnoreg fuzzyCCT fuzzyCERCCT FG max {

	rename bw_`k' bw_l_`k'
	rename b_bw_`k' b_bw_l_`k'
	
	gen bw_r_`k' = bw_l_`k'
	gen b_bw_r_`k' = b_bw_l_`k'
	
}

local bws "CCT CCTnoreg fuzzyCCT fuzzyTWO fuzzyCERCCT fuzzyCERTWO FG max"
foreach k of local bws { 

	qui gen absdev_cl_`k' = abs(tau_F_cl_`k' - truekink)
	qui gen devsq_cl_`k' = (tau_F_cl_`k'-truekink)^2
	qui gen devsq_T_cl_`k' = (tau_T_cl_`k'-truefs)^2
	qui gen dev_cl_`k' = tau_F_cl_`k'-truekink
	qui gen cover_zero_T_cl_`k' = (ci_upper_T_cl_`k'>0 & ci_lower_T_cl_`k' <0)
	
	qui sum devsq_cl_`k', d
	scalar rmse_cl_`k' = sqrt(r(mean)) 
	scalar tcutoff_cl_`k' = r(p95)
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar trmse_cl_`k' = sqrt(r(mean))
	
	qui sum dev_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tbias_cl_`k' = r(mean)
	
	qui sum tau_F_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tvar_cl_`k' = r(sd)^2

	
	qui sum absdev_cl_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_cl_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_cl_`k' if absdev_cl_`k'<r(p95)
	scalar tadr_cl_`k' = r(mean)
	
	
	//di "Coverage rates"
	qui sum cover_cl_`k'
	scalar cr_cl_`k' = r(mean)

	
	qui sum devsq_T_cl_`k'
	scalar rmse_T_cl_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_cl_`k'
	scalar cr_zero_T_cl_`k' = r(mean)
	
	qui sum cover_T_cl_`k'
	scalar cr_T_cl_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
	
	
	}

	
foreach k of local bws { 

	qui gen absdev_bc_`k' = abs(tau_F_bc_`k' - truekink)
	qui gen devsq_bc_`k' = (tau_F_bc_`k'-truekink)^2
	qui gen devsq_T_bc_`k' = (tau_T_bc_`k'-truefs)^2
	qui gen dev_bc_`k' = tau_F_bc_`k'-truekink
	qui gen cover_zero_T_rb_`k' = (ci_upper_T_rb_`k'>0 & ci_lower_T_rb_`k' <0)
		
	
	qui sum devsq_bc_`k', d
	scalar rmse_bc_`k' = sqrt(r(mean)) 
 	scalar tcutoff_bc_`k' = r(p95)
	
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar trmse_bc_`k' = sqrt(r(mean)) 
	
	qui sum dev_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tbias_bc_`k' = r(mean)
	
	qui sum tau_F_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tvar_rb_`k' = r(sd)^2
	
	
	
	qui sum absdev_bc_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_bc_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_bc_`k' if absdev_bc_`k'<r(p95)
	scalar tadr_bc_`k' = r(mean)

	qui sum devsq_T_bc_`k'
	scalar rmse_T_bc_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_rb_`k'
	scalar cr_zero_T_rb_`k' = r(mean)
	
	qui sum cover_T_rb_`k'
	scalar cr_T_rb_`k' = r(mean)	
	
	//di "Coverage rates"
	qui sum cover_rb_`k'
	scalar cr_rb_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)
	
	
	}


	
scalar mbw_max = 13908
scalar pbw_max = 13908	
						
di "BW Method " "RMSE  " "TRMSE  " "Coverage IV " "Coverage FS " "FS Cover 0 " "FS MSE " "Main BW (Left/right)" "Pilot BW (Left/right)"

foreach k of local bws { 

	di "`k'" " " rmse_cl_`k' " " trmse_cl_`k' " " cr_cl_`k' " " cr_T_cl_`k' " " cr_zero_T_cl_`k' " " rmse_T_cl_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_cl_`k' " " tbias_cl_`k'^2 " " tvar_cl_`k'
	
						}		

					
foreach k of local bws { 

	di "`k'" " " rmse_bc_`k' " " trmse_bc_`k' " " cr_rb_`k' " " cr_T_rb_`k' " " cr_zero_T_rb_`k' " " rmse_T_bc_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_bc_`k' " " tbias_bc_`k'^2 " " tvar_rb_`k'
	
						}	



/*
histogram tau_F_cl_FG, xline(2.0) xtitle("Local Linear FG Estimate") title("Distribution of Local Linear FG Estimate: Top Kink Quintic DGP")
graph export "C:\Users\pei\Dropbox\rdd3\graphs\dist_estimate_kink4_nk_quintic_llFG.pdf", as(pdf) replace	
*/							
						
							
/*
foreach k of local bws { 

	qui sum absdev_cl_`k', d
				
	scatter absdev_cl_`k' Fstat_T_cl_`k' if absdev_cl_`k'<r(p95), saving(devcl_vs_Fcl_k4_`k'_ll.gph, replace)						

						}

graph combine devcl_vs_Fcl_k4_CCT_ll.gph devcl_vs_Fcl_k4_CCTnoreg_ll.gph devcl_vs_Fcl_k4_fuzzyCCT_ll.gph devcl_vs_Fcl_k4_fuzzyIK_ll.gph	devcl_vs_Fcl_k4_FG_ll.gph	///
devcl_vs_Fcl_k4_max_ll.gph, saving(devcl_vs_Fcl_k4_ll.gph, replace)			
						

foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' Fstat_T_cl_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_Fcl_k4_`k'_ll.gph, replace)						

						}
						
graph combine devbc_vs_Fcl_k4_CCT_ll.gph devbc_vs_Fcl_k4_CCTnoreg_ll.gph devbc_vs_Fcl_k4_fuzzyCCT_ll.gph devbc_vs_Fcl_k4_fuzzyIK_ll.gph	devbc_vs_Fcl_k4_FG_ll.gph	///
devbc_vs_Fcl_k4_max_ll.gph, saving(devbc_vs_Fcl_k4_ll.gph, replace)							

		
foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' t_T_rb_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_trb_k4_`k'_ll.gph, replace)						

						}
						
graph combine devbc_vs_trb_k4_CCT_ll.gph devbc_vs_trb_k4_CCTnoreg_ll.gph devbc_vs_trb_k4_fuzzyCCT_ll.gph devbc_vs_trb_k4_fuzzyIK_ll.gph	devbc_vs_trb_k4_FG_ll.gph	///
devbc_vs_trb_k4_max_ll.gph, saving(devbc_vs_trb_k4_ll.gph, replace)							
*/						

use "data\sim_emp_kink4_nk_quintic_summary_lq.dta", clear

cap drop absdev* devsq*						
scalar truekink = 0
scalar truefs = -1.4*10^(-5)						
						
foreach k in CCT CCTnoreg fuzzyCCT fuzzyCERCCT FG max {

	rename bw_`k' bw_l_`k'
	rename b_bw_`k' b_bw_l_`k'
	
	gen bw_r_`k' = bw_l_`k'
	gen b_bw_r_`k' = b_bw_l_`k'
	
}

local bws "CCT CCTnoreg fuzzyCCT fuzzyTWO fuzzyCERCCT fuzzyCERTWO FG max"
foreach k of local bws { 

	qui gen absdev_cl_`k' = abs(tau_F_cl_`k' - truekink)
	qui gen devsq_cl_`k' = (tau_F_cl_`k'-truekink)^2
	qui gen devsq_T_cl_`k' = (tau_T_cl_`k'-truefs)^2
	qui gen dev_cl_`k' = tau_F_cl_`k'-truekink
	qui gen cover_zero_T_cl_`k' = (ci_upper_T_cl_`k'>0 & ci_lower_T_cl_`k' <0)
	
	qui sum devsq_cl_`k', d
	scalar rmse_cl_`k' = sqrt(r(mean)) 
	scalar tcutoff_cl_`k' = r(p95)
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar trmse_cl_`k' = sqrt(r(mean))
	
	qui sum dev_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tbias_cl_`k' = r(mean)
	
	qui sum tau_F_cl_`k' if devsq_cl_`k'<tcutoff_cl_`k'
	scalar tvar_cl_`k' = r(sd)^2

	
	qui sum absdev_cl_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_cl_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_cl_`k' if absdev_cl_`k'<r(p95)
	scalar tadr_cl_`k' = r(mean)
	
	
	//di "Coverage rates"
	qui sum cover_cl_`k'
	scalar cr_cl_`k' = r(mean)

	
	qui sum devsq_T_cl_`k'
	scalar rmse_T_cl_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_cl_`k'
	scalar cr_zero_T_cl_`k' = r(mean)
	
	qui sum cover_T_cl_`k'
	scalar cr_T_cl_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)	
	
	}

	
foreach k of local bws { 

	qui gen absdev_bc_`k' = abs(tau_F_bc_`k' - truekink)
	qui gen devsq_bc_`k' = (tau_F_bc_`k'-truekink)^2
	qui gen devsq_T_bc_`k' = (tau_T_bc_`k'-truefs)^2
	qui gen dev_bc_`k' = tau_F_bc_`k'-truekink
	qui gen cover_zero_T_rb_`k' = (ci_upper_T_rb_`k'>0 & ci_lower_T_rb_`k' <0)
		
	
	qui sum devsq_bc_`k', d
	scalar rmse_bc_`k' = sqrt(r(mean)) 
 	scalar tcutoff_bc_`k' = r(p95)
	
	
	//di "Trimmed Mean Squared Error"
	qui sum devsq_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar trmse_bc_`k' = sqrt(r(mean)) 
	
	qui sum dev_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tbias_bc_`k' = r(mean)
	
	qui sum tau_F_bc_`k' if devsq_bc_`k'<tcutoff_bc_`k'
	scalar tvar_rb_`k' = r(sd)^2
	
	
	
	qui sum absdev_bc_`k', d
	//di "Absolute deviation as a ratio"	r(mean)
	scalar adr_bc_`k' = r(mean)

	//di "Trimmed Absolute Deviatio as a ratio"
	qui sum absdev_bc_`k' if absdev_bc_`k'<r(p95)
	scalar tadr_bc_`k' = r(mean)

	qui sum devsq_T_bc_`k'
	scalar rmse_T_bc_`k' = sqrt(r(mean))/abs(truefs)
	
	qui sum cover_zero_T_rb_`k'
	scalar cr_zero_T_rb_`k' = r(mean)
	
	qui sum cover_T_rb_`k'
	scalar cr_T_rb_`k' = r(mean)	
	
	//di "Coverage rates"
	qui sum cover_rb_`k'
	scalar cr_rb_`k' = r(mean)
	
	//di "bandwidth"
	qui sum bw_l_`k', d
	scalar mbw_l_`k' = r(p50)

	qui sum bw_r_`k', d
	scalar mbw_r_`k' = r(p50)

	qui sum b_bw_l_`k', d
	scalar pbw_l_`k' = r(p50)
	
	qui sum b_bw_r_`k', d
	scalar pbw_r_`k' = r(p50)	
	
	}


	
scalar mbw_max = 13908
scalar pbw_max = 13908	
						
di "BW Method " "RMSE  " "TRMSE  " "Coverage IV " "Coverage FS " "FS Cover 0 " "FS MSE " "Main BW (Left/right)" "Pilot BW (Left/right)"

foreach k of local bws { 

	di "`k'" " " rmse_cl_`k' " " trmse_cl_`k' " " cr_cl_`k' " " cr_T_cl_`k' " " cr_zero_T_cl_`k' " " rmse_T_cl_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_cl_`k' " " tbias_cl_`k'^2 " " tvar_cl_`k'
	
						}		

					
foreach k of local bws { 

	di "`k'" " " rmse_bc_`k' " " trmse_bc_`k' " " cr_rb_`k' " " cr_T_rb_`k' " " cr_zero_T_rb_`k' " " rmse_T_bc_`k' " " mbw_l_`k' " " mbw_r_`k' " " pbw_l_`k' " " pbw_r_`k' " " tbias_bc_`k' " " tbias_bc_`k'^2 " " tvar_rb_`k'
	
						}	
log close
									
/*
foreach k of local bws { 

	qui sum absdev_cl_`k', d
				
	scatter absdev_cl_`k' Fstat_T_cl_`k' if absdev_cl_`k'<r(p95), saving(devcl_vs_Fcl_k4_`k'_lq.gph, replace)						

						}

graph combine devcl_vs_Fcl_k4_CCT_lq.gph devcl_vs_Fcl_k4_CCTnoreg_lq.gph devcl_vs_Fcl_k4_fuzzyCCT_lq.gph devcl_vs_Fcl_k4_fuzzyIK_lq.gph	devcl_vs_Fcl_k4_FG_lq.gph	///
devcl_vs_Fcl_k4_max_lq.gph, saving(devcl_vs_Fcl_k4_lq.gph, replace)			
						

foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' Fstat_T_cl_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_Fcl_k4_`k'_lq.gph, replace)						

						}
						
graph combine devbc_vs_Fcl_k4_CCT_lq.gph devbc_vs_Fcl_k4_CCTnoreg_lq.gph devbc_vs_Fcl_k4_fuzzyCCT_lq.gph devbc_vs_Fcl_k4_fuzzyIK_lq.gph	devbc_vs_Fcl_k4_FG_lq.gph	///
devbc_vs_Fcl_k4_max_lq.gph, saving(devbc_vs_Fcl_k4_lq.gph, replace)							

		
foreach k of local bws { 

	qui sum absdev_bc_`k', d
				
	scatter absdev_bc_`k' t_T_rb_`k' if absdev_bc_`k'<r(p95), saving(devbc_vs_trb_k4_`k'_lq.gph, replace)						

						}
						
graph combine devbc_vs_trb_k4_CCT_lq.gph devbc_vs_trb_k4_CCTnoreg_lq.gph devbc_vs_trb_k4_fuzzyCCT_lq.gph devbc_vs_trb_k4_fuzzyIK_lq.gph	devbc_vs_trb_k4_FG_lq.gph	///
devbc_vs_trb_k4_max_lq.gph, saving(devbc_vs_trb_k4_lq.gph, replace)							
*/						
